import { FC } from "react";
import { ECS, UntypedEntity } from ".";
import { ComponentName, IEntity } from "./ecs";
/**
 * Create various React-specific hooks and components for your
 * Miniplex ECS instance.
 *
 * @param ecs An instance of a Miniplex ECS to use.
 */
export declare function createReactIntegration<T extends IEntity = UntypedEntity>(ecs: ECS<T>): {
    useArchetype: (...names: ComponentName<T>[]) => T[];
    Entity: FC<{}>;
    Component: <K extends keyof T>({ name, data }: {
        name: K;
        data: T[K];
    }) => null;
    entities: T[];
    immediately: {
        addEntity: (entity: T) => T;
        removeEntity: (entity: T) => void;
        addComponent: <U extends keyof T>(entity: T, name: U, data: T[U]) => void;
        removeComponent: (entity: T, ...names: (keyof T)[]) => void;
    };
    createArchetype: (...components: (keyof T)[]) => import("./ecs").Archetype<T>;
    get: (archetype: import("./ecs").Archetype<T>) => T[];
    getWith: (...components: (keyof T)[]) => T[];
    flush: () => void;
    addEntity: (entity: T) => T;
    removeEntity: (entity: T) => void;
    addComponent: <U extends keyof T>(entity: T, name: U, data: T[U]) => void;
    removeComponent: (entity: T, ...names: (keyof T)[]) => void;
    listeners: {
        archetypeChanged: Map<import("./ecs").Archetype<T>, import("./util/ListenerRegistry").ListenerRegistry<Function>>;
    };
};
