import { jsx as _jsx } from "react/jsx-runtime";
import { createContext, useContext, useEffect, useState } from "react";
import { useRerender } from "./util/useRerender";
/**
 * Create various React-specific hooks and components for your
 * Miniplex ECS instance.
 *
 * @param ecs An instance of a Miniplex ECS to use.
 */
export function createReactIntegration(ecs) {
    function useArchetype(...names) {
        const rerender = useRerender();
        const archetype = ecs.createArchetype(...names);
        useEffect(() => {
            ecs.listeners.archetypeChanged.get(archetype).on(rerender);
            return () => ecs.listeners.archetypeChanged.get(archetype).off(rerender);
        }, [ecs]);
        return ecs.get(archetype);
    }
    const EntityContext = createContext(null);
    const Entity = ({ children }) => {
        const [entity] = useState(() => ({}));
        useEffect(() => {
            ecs.addEntity(entity);
            return () => ecs.removeEntity(entity);
        }, [entity]);
        return _jsx(EntityContext.Provider, { value: entity, children: children }, void 0);
    };
    function Component({ name, data }) {
        const entity = useContext(EntityContext);
        useEffect(() => {
            ecs.addComponent(entity, name, data);
            return () => ecs.removeComponent(entity, name);
        }, [entity, name, data]);
        return null;
    }
    return { ...ecs, useArchetype, Entity, Component };
}
